==> hlw-core-0.0.2-20250904.011858-147-sources.jar: cn/gtmap/hlw/core/dto/exchange/push/PushTdxxDTO.java <==
package cn.gtmap.hlw.core.dto.exchange.push;

import cn.gtmap.hlw.core.annotation.ZdTypeConfig;
import cn.gtmap.hlw.core.constant.dict.ZdTypeConstant;
import lombok.Data;

/**
 * @author <a href="mailto:dingweiwei@gtmap.cn">dingweiwei</a>
 * @version 1.0, 2025/4/1
 * @description
 */
@Data
public class PushTdxxDTO {
    /**受理编号 （与sqxx表关联）*/
    private String slbh;

    /** 宗地号*/
    private String zdh;

    /** 宗地面积*/
    private String zdmj;

    private String tdsyqlx;
    /** 土地使用权类型名称*/
    @ZdTypeConfig(field = "tdsyqlx", tableName = ZdTypeConstant.ZD_TYPE_QLXZ, dmToMc = true)
    private String tdsyqlxmc;

    /** 土地用途*/
    private String tdyt;

    /** 土地用途*/
    @ZdTypeConfig(field = "tdyt", tableName = ZdTypeConstant.ZD_TYPE_TDYT, dmToMc = true)
    private String tdytmc;

    /**申请id*/
    private String sqid;

    /** 土地证号*/
    private String tdzh;

    /** 土地使用权人*/
    private String tdsyqr;

    /** 土地使用权面积*/
    private String tdsyqmj;

    /** 独用土地面积*/
    private String dytdmj;

    /** 分摊土地面积*/
    private String fttdmj;

    /** 项目id*/
    private String xmid;

    /** 证书来源*/
    private String zsly;

    /** 不动产单元号*/
    private String bdcdyh;

    /** 附记*/
    private String fj;

    /** 土地使用起始时间*/
    private String tdsyqssj;

    /** 土地使用结束时间*/
    private String tdsyjssj;

    /** 土地坐落*/
    private String tdzl;

    /** 宗地四至东*/
    private String zdszd;

    /** 宗地四至南*/
    private String zdszn;

    /** 宗地四至西*/
    private String zdszx;

    /** 宗地四至北*/
    private String zdszb;

    /** 土地用途2*/
    private String tdyt2;

    /** 土地用途3*/
    private String tdyt3;

    /** 土地使用起始时间2*/
    private String tdsyqssj2;

    /** 土地使用起始时间3*/
    private String tdsyqssj3;

    /** 土地使用结束时间2*/
    private String tdsyjssj2;

    /** 土地使用结束时间3*/
    private String tdsyjssj3;

    /** 批准面积*/
    private String pzmj;

    /** 农用地面积*/
    private String nydmj;

    /** 建设用地面积*/
    private String jsydmj;

    /** 未利用地面积*/
    private String wlydmj;

    /** 耕地面积*/
    private String gdmj;

    /** 林地面积*/
    private String ldmj;

    /**草地面积*/
    private String cdmj;

    /**其他面积*/
    private String qtmj;

    /**宗地宗海权利类型代码（zd_type表对照）*/
    private String zdzhqllx;

    /**取得方式（存放代码）*/
    private String qdfs;

    /** 容积率*/
    private String rjl;

    /** 土地使用期限*/
    private String tdsyqx;
}

==> hlw-core-0.0.2-20251104.094831-170-sources.jar: cn/gtmap/hlw/core/dto/exchange/push/PushTdxxDTO.java <==
package cn.gtmap.hlw.core.dto.exchange.push;

import cn.gtmap.hlw.core.annotation.ZdTypeConfig;
import cn.gtmap.hlw.core.constant.dict.ZdTypeConstant;
import lombok.Data;

/**
 * @author <a href="mailto:dingweiwei@gtmap.cn">dingweiwei</a>
 * @version 1.0, 2025/4/1
 * @description
 */
@Data
public class PushTdxxDTO {
    /**受理编号 （与sqxx表关联）*/
    private String slbh;

    /** 宗地号*/
    private String zdh;

    /** 宗地面积*/
    private String zdmj;

    private String tdsyqlx;
    /** 土地使用权类型名称*/
    @ZdTypeConfig(field = "tdsyqlx", tableName = ZdTypeConstant.ZD_TYPE_QLXZ, dmToMc = true)
    private String tdsyqlxmc;

    /** 土地用途*/
    private String tdyt;

    /** 土地用途*/
    @ZdTypeConfig(field = "tdyt", tableName = ZdTypeConstant.ZD_TYPE_TDYT, dmToMc = true)
    private String tdytmc;

    /**申请id*/
    private String sqid;

    /** 土地证号*/
    private String tdzh;

    /** 土地使用权人*/
    private String tdsyqr;

    /** 土地使用权面积*/
    private String tdsyqmj;

    /** 独用土地面积*/
    private String dytdmj;

    /** 分摊土地面积*/
    private String fttdmj;

    /** 项目id*/
    private String xmid;

    /** 证书来源*/
    private String zsly;

    /** 不动产单元号*/
    private String bdcdyh;

    /** 附记*/
    private String fj;

    /** 土地使用起始时间*/
    private String tdsyqssj;

    /** 土地使用结束时间*/
    private String tdsyjssj;

    /** 土地坐落*/
    private String tdzl;

    /** 宗地四至东*/
    private String zdszd;

    /** 宗地四至南*/
    private String zdszn;

    /** 宗地四至西*/
    private String zdszx;

    /** 宗地四至北*/
    private String zdszb;

    /** 土地用途2*/
    private String tdyt2;

    /** 土地用途3*/
    private String tdyt3;

    /** 土地使用起始时间2*/
    private String tdsyqssj2;

    /** 土地使用起始时间3*/
    private String tdsyqssj3;

    /** 土地使用结束时间2*/
    private String tdsyjssj2;

    /** 土地使用结束时间3*/
    private String tdsyjssj3;

    /** 批准面积*/
    private String pzmj;

    /** 农用地面积*/
    private String nydmj;

    /** 建设用地面积*/
    private String jsydmj;

    /** 未利用地面积*/
    private String wlydmj;

    /** 耕地面积*/
    private String gdmj;

    /** 林地面积*/
    private String ldmj;

    /**草地面积*/
    private String cdmj;

    /**其他面积*/
    private String qtmj;

    /**宗地宗海权利类型代码（zd_type表对照）*/
    private String zdzhqllx;

    /**取得方式（存放代码）*/
    private String qdfs;

    /** 容积率*/
    private String rjl;

    /** 土地使用期限*/
    private String tdsyqx1;

    /** 土地使用期限*/
    @ZdTypeConfig(field = "tdsyqx1", tableName = ZdTypeConstant.ZD_TYPE_TDSYQX, dmToMc = true)
    private String tdsyqx1mc;
}
